package servlet;

import java.io.File;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.FileUploadException;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.servlet.ServletFileUpload;
import org.jets3t.service.S3Service;
import org.jets3t.service.S3ServiceException;
import org.jets3t.service.impl.rest.httpclient.RestS3Service;
import org.jets3t.service.model.S3Object;
import org.jets3t.service.security.AWSCredentials;

import com.amazonaws.auth.PropertiesCredentials;

public class UploadServlet extends HttpServlet {
	private static final String BUCKET_NAME = "nikkei-soft-fileupload-bucket";
	private static final long serialVersionUID = 1L;

	private S3Service s3Service;

	@Override
	public void init() throws ServletException {
		super.init();

		try {
			PropertiesCredentials credentials = new PropertiesCredentials(
					getClass().getClassLoader().getResourceAsStream(
							"AwsCredentials.properties"));

			this.s3Service = new RestS3Service(new AWSCredentials(
					credentials.getAWSAccessKeyId(),
					credentials.getAWSSecretKey()));
		} catch (IOException e) {
			e.printStackTrace();
		} catch (S3ServiceException e) {
			e.printStackTrace();
		}
	}

	public void doGet(HttpServletRequest request, HttpServletResponse response)
			throws ServletException, IOException {

		try {
			S3Object[] s3objects = s3Service.listObjects(BUCKET_NAME);
			request.getSession().setAttribute("s3objects", s3objects);
		} catch (S3ServiceException e) {
			e.printStackTrace();
		}

		RequestDispatcher rd = request.getRequestDispatcher("upload.jsp");
		rd.forward(request, response);
	}

	public void doPost(HttpServletRequest request, HttpServletResponse response)
			throws ServletException, IOException {

		DiskFileItemFactory factory = new DiskFileItemFactory();
		ServletFileUpload sfu = new ServletFileUpload(factory);
		sfu.setHeaderEncoding("utf-8");

		try {
			List list = sfu.parseRequest(request);
			Iterator iterator = list.iterator();

			while (iterator.hasNext()) {
				FileItem item = (FileItem) iterator.next();

				if (!item.isFormField()) {
					String filename = item.getName();

					if ((filename != null) && (!filename.equals(""))) {
						filename = (new File(filename)).getName();
						File fileData = new File(filename);
						item.write(fileData);

						s3Service.putObject(
								s3Service.createBucket(BUCKET_NAME),
								new S3Object(fileData));
					}
				}
			}
		} catch (FileUploadException e) {
			e.printStackTrace();
		} catch (Exception e) {
			e.printStackTrace();
		}

		response.sendRedirect("file");
	}
}